Learn R Programming

siebanxicor (version 1.0.0)

getSerieDataFrame: Get a data.frame from an series Vector

Description

This is an utility function, it allows to obtain a data.frame from the vector returned by getSeriesData.

Usage

getSerieDataFrame(series, idSerie)

Arguments

series

A vector containing data series. This is the vector returned by getSeriesData.

idSerie

A string intentifying the series required, it can only be one.

Value

A data.frame containing the required data series.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
## You need a valid token to run the example
setToken("token")

series <- getSeriesMetadata(c("SF43718","SF46410","SF46407"))

serie <- getSerieDataFrame(series, "SF43718")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab