Learn R Programming

siebanxicor (version 1.0.0)

getSeriesCurrentValue: Time series current value

Description

Recovers last value of the indicated time series (up to 100) from SIE.

Usage

getSeriesCurrentValue(series)

Arguments

series

A vector containing idSeries

Value

A data.frame containing the data series requested.

Details

This function queries the last value of each series requested. This value corresponds to the last one published by Banco de M<U+00E9>xico.

The data series are queried throught the SIE API. This API requieres that every request is identified by a token. The token can be requested here. Once the query token has been obtained and prior to use any function from this Package, the token must be set in the current query session, using the function setToken.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
## You need a valid token to run the example
setToken(token)
idSeries <- c("SF43718","SF46410","SF46407")
seriesDataFrame <- getSeriesCurrentValue(idSeries)

serieDataFrame <- getSeriesCurrentValue("SF43718")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab