Learn R Programming

siebanxicor (version 1.0.0)

getSeriesData: Query time series

Description

Recovers data of the indicated time series (up to 100) from SIE.

Usage

getSeriesData(series, startDate = NULL, endDate = NULL)

Arguments

series

A vector containing idSeries

startDate

A string with "yyyy-MM-dd" format. Defines the date on which the period of obtained data starts.

endDate

A string with "yyyy-MM-dd" format. Defines the date on which the period of obtained data concludes.

Value

A vector containing the data series requested.

Details

The data series are queried throught the SIE API. This API requieres that every request is identified by a token. The token can be requested here. Once the query token has been obtained and prior to use any function from this Package, the token must be set in the current query session, using the function setToken.

To get a data.frame representing one data series use getSerieDataFrame.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
## You need a valid token to run the example
setToken("token")
idSeries <- c("SF43718","SF46410","SF46407")
series <- getSeriesData(idSeries, '2016-01-01','2018-07-12')

serie <- getSeriesData("SF43718")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab