Learn R Programming

siebanxicor (version 1.0.0)

getSeriesMetadata: Query time series metadata

Description

Recovers metadata of the indicated time series (up to 100) from SIE.

Usage

getSeriesMetadata(series, locale = "en")

Arguments

series

A vector containing idSeries.

locale

A string defining the language of the metadata. It can be obtained either in English ("en") or Spanish ("es").

Value

A data.frame containing the required metadata.

Details

The series metadata are queried throught the SIE API. This API requieres that every request is identified by a token. The token can be requested here. Once the query token has been obtained and prior to use any function from this Package, the token must be set in the current query session, using the function setToken.

The information can be obtained either in English ("en") or Spanish ("es"), defining the parameter locale. By default the metadata are retrieved in English.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
## You need a valid token to run the example
setToken(token)
series <- getSeriesMetadata(c("SF43718","SF46410","SF46407"))

serie <- getSeriesMetadata("SF43718")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab